@@ -60,11 +60,13 @@ class Instance(object):
         if "default" in kwargs:
             attribute_doesnt_exist = default_value
             value = kwargs["default"]
-
         elif len(arg) == 1:
             attribute_doesnt_exist = default_value
             value = arg[0]
 
+        if name is None:
+            return attribute_doesnt_exist(name, value)
+
         if name == "prediction":
             return self.prediction
 
