@@ -10,7 +10,7 @@ from importlib import import_module
 from alira.instance import Instance
 from alira.modules.redis import RedisModule, ServiceException
 
-from botocore.exceptions import ClientError, EndpointConnectionError
+from botocore.exceptions import ClientError, EndpointConnectionError, InvalidConfigError
 
 from twilio.rest import Client
 from twilio.base.exceptions import TwilioRestException
@@ -279,9 +279,15 @@ class SocketIO(object):
 
 
 class TwilioSmsNotificationProvider(object):
-    def __init__(self, account_sid: str, auth_token: str, **kwargs):
-        self.account_sid = account_sid
-        self.auth_token = auth_token
+    def __init__(self, account_sid: str = None, auth_token: str = None, **kwargs):
+
+        self.account_sid = account_sid or os.environ.get(
+            "ALIRA_TWILIO_ACCOUNT_SID", None
+        )
+        self.auth_token = auth_token or os.environ.get("ALIRA_TWILIO_AUTH_TOKEN", None)
+
+        if not self.account_sid or not self.auth_token:
+            raise RuntimeError("The Twilio credentials were not specified")
 
     def send_sms(
         self,
@@ -330,11 +336,28 @@ class TwilioSmsNotificationProvider(object):
 
 class AwsSesEmailNotificationProvider(object):
     def __init__(
-        self, aws_access_key: str, aws_secret_key: str, aws_region_name: str, **kwargs
+        self,
+        aws_access_key: str = None,
+        aws_secret_key: str = None,
+        aws_region_name: str = None,
+        **kwargs,
     ):
-        self.aws_access_key = aws_access_key
-        self.aws_secret_key = aws_secret_key
-        self.aws_region_name = aws_region_name
+        self.aws_access_key = aws_access_key or os.environ.get(
+            "ALIRA_AWS_ACCESS_KEY_ID", None
+        )
+        self.aws_secret_key = aws_secret_key or os.environ.get(
+            "ALIRA_AWS_SECRET_ACCESS_KEY", None
+        )
+        self.aws_region_name = aws_region_name or os.environ.get(
+            "ALIRA_AWS_REGION_NAME", None
+        )
+
+        if (
+            not self.aws_access_key
+            or not self.aws_secret_key
+            or not self.aws_region_name
+        ):
+            raise RuntimeError("The AWS credentials were not specified")
 
     def send_email(
         self,
