@@ -82,10 +82,10 @@ class S3(RedisModule):
         aws_s3_bucket: str,
         aws_s3_key_prefix: str,
         aws_s3_public: bool,
-        aws_access_key: str,
-        aws_secret_key: str,
-        aws_region_name: str,
         module_id: str = None,
+        aws_access_key: str = None,
+        aws_secret_key: str = None,
+        aws_region_name: str = None,
         autogenerate_name: bool = False,
         redis_server: str = None,
         filtering: str = None,
@@ -100,9 +100,15 @@ class S3(RedisModule):
             redis_server=redis_server,
         )
 
-        self.aws_access_key = aws_access_key
-        self.aws_secret_key = aws_secret_key
-        self.aws_region_name = aws_region_name
+        self.aws_access_key = aws_access_key or os.environ.get(
+            "ALIRA_AWS_ACCESS_KEY_ID", None
+        )
+        self.aws_secret_key = aws_secret_key or os.environ.get(
+            "ALIRA_AWS_SECRET_ACCESS_KEY", None
+        )
+        self.aws_region_name = aws_region_name or os.environ.get(
+            "ALIRA_AWS_REGION_NAME", None
+        )
 
         self.filtering = self._load_function(filtering)
         self.aws_s3_bucket = aws_s3_bucket
@@ -128,7 +134,7 @@ class S3(RedisModule):
         if self.file:
             filename = instance.get_attribute(self.file, default=instance.image)
         else:
-            filename = os.path.join("images", instance.image)
+            filename = instance.image
 
         if self.autogenerate_name:
             _, file_extension = os.path.splitext(filename)
@@ -139,7 +145,7 @@ class S3(RedisModule):
         if self.aws_s3_key_prefix:
             s3_key = f"{self.aws_s3_key_prefix}/{s3_key}"
 
-        filename = os.path.join(self.configuration_directory, filename)
+        filename = os.path.join(self.configuration_directory, "images", filename)
 
         if not os.path.isfile(filename):
             logging.info(f"The file {filename} does not exist")
