@@ -59,9 +59,6 @@ class Pipeline(object):
         configuration_directory: str = None,
         store_configuration: dict = None,
         redis_server: str = None,
-        aws_access_key: str = None,
-        aws_secret_key: str = None,
-        aws_region_name: str = None,
         **kwargs,
     ):
         self.kwargs = kwargs
@@ -71,9 +68,6 @@ class Pipeline(object):
         )
 
         self.redis_server = redis_server
-        self.aws_access_key = aws_access_key
-        self.aws_secret_key = aws_secret_key
-        self.aws_region_name = aws_region_name
 
         # We are going to read the model identifier and the list of
         # modules from the pipeline.yml file.
@@ -178,18 +172,6 @@ class Pipeline(object):
 
         pipeline = pipeline_configuration.get("pipeline", [])
 
-        # If the pipeline defines a set of AWS credentials, we want to overwrite the
-        # credentials that were passed in.
-        self.aws_access_key = pipeline_configuration.get(
-            "aws_access_key", self.aws_access_key
-        )
-        self.aws_secret_key = pipeline_configuration.get(
-            "aws_secret_key", self.aws_secret_key
-        )
-        self.aws_region_name = pipeline_configuration.get(
-            "aws_region_name", self.aws_region_name
-        )
-
         for module_configuration in pipeline:
             try:
                 module_path, _, module_name = module_configuration["module"].rpartition(
@@ -209,9 +191,6 @@ class Pipeline(object):
                 arguments[argument_id] = argument
 
             arguments["redis_server"] = self.redis_server
-            arguments["aws_access_key"] = self.aws_access_key
-            arguments["aws_secret_key"] = self.aws_secret_key
-            arguments["aws_region_name"] = self.aws_region_name
 
             arguments.update(self.kwargs)
             self.modules.append(module(**arguments))
